@@ -262,7 +262,7 @@ void checkGrid(const Grid& grid)
 int main(int argc, char** argv)
 try
 {
-  // initialize MPI if neccessary
+  // initialize MPI if necessary
   Dune::MPIHelper::instance(argc, argv);
 
   // Check grids with more than one element type.
@@ -274,7 +274,7 @@ try
     std::unique_ptr<Grid> grid(make2DHybridTestGrid<Grid>());
 
     // create hybrid grid
-    grid->mark(1, * grid->leafbegin<0>());
+    grid->mark(1, grid->leafGridView().begin<0>());
     grid->adapt();
     grid->globalRefine(1);
 
@@ -287,7 +287,7 @@ try
     std::unique_ptr<Grid> grid(make3DHybridTestGrid<Grid>());
 
     // create hybrid grid
-    grid->mark(1, * grid->leafbegin<0>());
+    grid->mark(1, grid->leafGridView().begin<0>());
     grid->adapt();
     grid->globalRefine(1);
 
