@@ -133,7 +133,7 @@ int doWrite( const GridView &gridView, Dune :: VTK :: DataMode dm )
 }
 
 template<int dim>
-int vtkCheck(const Dune::array<int, dim>& elements,
+int vtkCheck(const std::array<int, dim>& elements,
               const Dune::FieldVector<double, dim>& upperRight)
 {
   Dune::YaspGrid<dim> g(upperRight, elements);
@@ -147,15 +147,15 @@ int vtkCheck(const Dune::array<int, dim>& elements,
 
   int result = 0;
 
-  acc(result, doWrite( g.template leafGridView(), Dune::VTK::conforming ));
-  acc(result, doWrite( g.template leafGridView(), Dune::VTK::nonconforming ));
-  acc(result, doWrite( g.template levelGridView( 0 ),
+  acc(result, doWrite( g.leafGridView(), Dune::VTK::conforming ));
+  acc(result, doWrite( g.leafGridView(), Dune::VTK::nonconforming ));
+  acc(result, doWrite( g.levelGridView( 0 ),
                        Dune::VTK::conforming ));
-  acc(result, doWrite( g.template levelGridView( 0 ),
+  acc(result, doWrite( g.levelGridView( 0 ),
                        Dune::VTK::nonconforming ));
-  acc(result, doWrite( g.template levelGridView( g.maxLevel() ),
+  acc(result, doWrite( g.levelGridView( g.maxLevel() ),
                        Dune::VTK::conforming ));
-  acc(result, doWrite( g.template levelGridView( g.maxLevel() ),
+  acc(result, doWrite( g.levelGridView( g.maxLevel() ),
                        Dune::VTK::nonconforming ));
 
   return result;
