@@ -5,8 +5,8 @@
 #include <dune/grid/uggrid.hh>
 #include <dune/grid/uggrid/uggridintersections.hh>
 
+#include <list>
 #include <set>
-#include <forward_list>
 
 template<class GridImp>
 const typename Dune::UGGridLevelIntersection<GridImp>::WorldVector&
@@ -577,7 +577,6 @@ int Dune::UGGridLeafIntersection<GridImp>::getFatherSide(const Face& currentFace
     }
 
     DUNE_THROW(InvalidStateException,"getFatherSide() didn't find a father.");
-    return 0;
 
   } else {    //  dim==3
 
@@ -634,7 +633,7 @@ int Dune::UGGridLeafIntersection<GridImp>::getFatherSide(const Face& currentFace
   }
 
   // Should never happen
-  return -1;
+  DUNE_THROW(GridError, "Reached code path that should never be reached");
 }
 
 template< class GridImp>
@@ -697,27 +696,10 @@ void Dune::UGGridLeafIntersection<GridImp>::constructLeafSubfaces() {
 
   else {
 
-    std::forward_list<Face> list;
-    int levelNeighborSide = numberInNeighbor(center_, levelNeighbor);
+    std::list<Face> list;
 
-    UG::INT Sons_of_Side = 0;
-    typename UG_NS<dim>::Element* SonList[UG_NS<dim>::MAX_SONS];
-    UG::INT SonSides[UG_NS<dim>::MAX_SONS];
-
-    int rv = Get_Sons_of_ElementSide(levelNeighbor,
-                                     levelNeighborSide,
-                                     &Sons_of_Side,
-                                     SonList,      // the output elements
-                                     SonSides,     // Output element side numbers
-                                     true,        // Element sons are not precomputed
-                                     false,        // ioflag: Obsolete debugging flag
-                                     true);
-
-    if (rv!=0)
-      DUNE_THROW(GridError, "Get_Sons_of_ElementSide returned with error value " << rv);
-
-    for (int i=0; i<Sons_of_Side; i++)
-      list.push_front(Face(SonList[i],SonSides[i]));
+    const int levelNeighborSide = numberInNeighbor(center_, levelNeighbor);
+    list.emplace_back(levelNeighbor, levelNeighborSide);
 
     // //////////////////////////////////////////////////
     //   Get_Sons_of_ElementSide only computes direct sons.  Therefore in order to get all
@@ -735,22 +717,30 @@ void Dune::UGGridLeafIntersection<GridImp>::constructLeafSubfaces() {
 
       if (!UG_NS<dim>::isLeaf(theElement)) {
 
-        Get_Sons_of_ElementSide(theElement,
-                                f.second,      // Input element side number
-                                &Sons_of_Side,     // Number of topological sons of the element side
-                                SonList,          // Output elements
-                                SonSides,         // Output element side numbers
-                                true,
-                                false,
-                                true);
+        int rv = Get_Sons_of_ElementSide(theElement,
+                                         f.second,      // Input element side number
+                                         &Sons_of_Side, // Number of topological sons of the element side
+                                         SonList,       // Output elements
+                                         SonSides,      // Output element side numbers
+                                         true,
+                                         false,
+                                         true);
+
+        if (rv!=0)
+          DUNE_THROW(GridError, "Get_Sons_of_ElementSide returned with error value " << rv);
 
         for (int i=0; i<Sons_of_Side; i++)
-          list.push_front(Face(SonList[i],SonSides[i]));
+          list.emplace_back(SonList[i], SonSides[i]);
 
       }
 
     }
 
+    // Remove the element itself.
+    // We are only interested in leaf elements and in this code branch
+    // the element we start with is never a leaf.
+    list.pop_front();
+
     // //////////////////////////////
     //   Extract result from stack
     // //////////////////////////////
